@@ -1,11 +1,9 @@
-from __future__ import absolute_import
-
 import sys
 import os
 
 from ..backend import KeyringBackend
 from ..errors import PasswordDeleteError
-from ..errors import PasswordSetError
+from ..errors import PasswordSetError, InitError, KeyringLocked
 from ..util import properties
 
 try:
@@ -48,7 +46,7 @@ class DBusKeyring(KeyringBackend):
         return 4.9
 
     def __init__(self, *arg, **kw):
-        super(DBusKeyring, self).__init__(*arg, **kw)
+        super().__init__(*arg, **kw)
         self.handle = -1
 
     def _migrate(self, service):
@@ -56,7 +54,8 @@ class DBusKeyring(KeyringBackend):
         entry_list = []
         if self.iface.hasFolder(self.handle, old_folder, self.appid):
             entry_list = self.iface.readPasswordList(
-                self.handle, old_folder, '*@*', self.appid)
+                self.handle, old_folder, '*@*', self.appid
+            )
 
             for entry in entry_list.items():
                 key = entry[0]
@@ -64,28 +63,31 @@ class DBusKeyring(KeyringBackend):
 
                 username, service = key.rsplit('@', 1)
                 ret = self.iface.writePassword(
-                    self.handle, service, username, password, self.appid)
+                    self.handle, service, username, password, self.appid
+                )
                 if ret == 0:
-                    self.iface.removeEntry(
-                        self.handle, old_folder, key, self.appid)
+                    self.iface.removeEntry(self.handle, old_folder, key, self.appid)
 
             entry_list = self.iface.readPasswordList(
-                self.handle, old_folder, '*', self.appid)
+                self.handle, old_folder, '*', self.appid
+            )
             if not entry_list:
                 self.iface.removeFolder(self.handle, old_folder, self.appid)
 
     def connected(self, service):
         if self.handle >= 0:
-            return True
+            if self.iface.isOpen(self.handle):
+                return True
+
         bus = dbus.SessionBus(mainloop=DBusGMainLoop())
         wId = 0
         try:
             remote_obj = bus.get_object(self.bus_name, self.object_path)
             self.iface = dbus.Interface(remote_obj, 'org.kde.KWallet')
-            self.handle = self.iface.open(
-                self.iface.networkWallet(), wId, self.appid)
-        except dbus.DBusException:
-            self.handle = -1
+            self.handle = self.iface.open(self.iface.networkWallet(), wId, self.appid)
+        except dbus.DBusException as e:
+            raise InitError('Failed to open keyring: %s.' % e)
+
         if self.handle < 0:
             return False
         self._migrate(service)
@@ -96,11 +98,10 @@ class DBusKeyring(KeyringBackend):
         """
         if not self.connected(service):
             # the user pressed "cancel" when prompted to unlock their keyring.
-            return None
+            raise KeyringLocked("Failed to unlock the keyring!")
         if not self.iface.hasEntry(self.handle, service, username, self.appid):
             return None
-        password = self.iface.readPassword(
-            self.handle, service, username, self.appid)
+        password = self.iface.readPassword(self.handle, service, username, self.appid)
         return str(password)
 
     def set_password(self, service, username, password):
@@ -109,8 +110,7 @@ class DBusKeyring(KeyringBackend):
         if not self.connected(service):
             # the user pressed "cancel" when prompted to unlock their keyring.
             raise PasswordSetError("Cancelled by user")
-        self.iface.writePassword(
-            self.handle, service, username, password, self.appid)
+        self.iface.writePassword(self.handle, service, username, password, self.appid)
 
     def delete_password(self, service, username):
         """Delete the password for the username of the service.
@@ -134,4 +134,4 @@ class DBusKeyringKWallet4(DBusKeyring):
     @properties.ClassProperty
     @classmethod
     def priority(cls):
-        return super(DBusKeyringKWallet4, cls).priority - 1
+        return super().priority - 1
