@@ -24,6 +24,7 @@ def set_keyring(keyring):
     if not isinstance(keyring, backend.KeyringBackend):
         raise TypeError("The keyring must be a subclass of KeyringBackend")
     _keyring_backend = keyring
+    keyring.set_properties_from_env()
 
 
 def get_keyring():
@@ -87,13 +88,15 @@ def init_backend(limit=None):
     # save the limit for the chainer to honor
     backend._limit = limit
 
-    # get all keyrings passing the limit filter
-    keyrings = filter(limit, backend.get_all_keyring())
-
     set_keyring(
         load_env()
         or load_config()
-        or max(keyrings, default=fail.Keyring(), key=backend.by_priority)
+        or max(
+            # all keyrings passing the limit filter
+            filter(limit, backend.get_all_keyring()),
+            default=fail.Keyring(),
+            key=backend.by_priority,
+        )
     )
 
 
