@@ -1,6 +1,9 @@
 import sys
 
 
+__metaclass__ = type
+
+
 class KeyringError(Exception):
     """Base class for exceptions in keyring
     """
@@ -26,7 +29,7 @@ class KeyringLocked(KeyringError):
     """
 
 
-class ExceptionRaisedContext(object):
+class ExceptionRaisedContext:
     """
     An exception-trapping context that indicates whether an exception was
     raised.
@@ -43,14 +46,15 @@ class ExceptionRaisedContext(object):
     def __exit__(self, *exc_info):
         self.exc_info.__init__(*exc_info)
         return self.exc_info.type and issubclass(
-            self.exc_info.type, self.ExpectedException)
+            self.exc_info.type, self.ExpectedException
+        )
 
 
-class ExceptionInfo(object):
+class ExceptionInfo:
     def __init__(self, *info):
         if not info:
             info = sys.exc_info()
-        self.type, self.value, self.traceback = info
+        self.type, self.value, _ = info
 
     def __bool__(self):
         """
